==> worker-2.8.3.tar.bz2: worker-2.8.3/src/aguix/cyclebutton.h <==
/* cyclebutton.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: cyclebutton.h,v 1.4 2001/11/03 17:15:18 ralf Exp $ */

#ifndef CYCLEBUTTON_H
#define CYCLEBUTTON_H

#include "aguixdefs.h"
#include "guielement.h"

class AWindow;
class AGUIXFont;
class List;

class CycleButton:public GUIElement {
public:
  CycleButton(AGUIX *aguix);
  CycleButton(AGUIX *aguix,int x,int y,int width,
              int fg,int bg,int data);
  CycleButton(AGUIX *aguix,int x,int y,int width,int height,
              int fg,int bg,int data);
  virtual ~CycleButton();
  char *getOption(int);
  int addOption(const char *);
  int getSelectedOption();
  void setFG(int);
  int getFG();
  void setBG(int);
  int getBG();
  int getData();
  void setData(int);
  void setState(int);
  int getState();
  virtual void redraw();
  virtual void flush();
  bool isInside(int x,int y);
  virtual bool handleMessage(XEvent *E,Message *msg);
  int setFont(char*);
  virtual const char *getType();
  virtual bool isType(const char *type);
  void setOption(int index);
  int getMaxSize();
protected:
  List *options;
  int act_opt;
  int fg;
  int bg;
  int lastbg;
  int data;
  int state;
  int instate;
  AGUIXFont *font;
  static const char *type;
};

#endif

==> worker-2.13.1.tar.bz2: worker-2.13.1/src/aguix/cyclebutton.h <==
/* cyclebutton.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2005 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: cyclebutton.h,v 1.10 2005/10/05 19:39:15 ralf Exp $ */

#ifndef CYCLEBUTTON_H
#define CYCLEBUTTON_H

#include "aguixdefs.h"
#include "guielement.h"

class AWindow;
class AGUIXFont;
class List;

class CycleButton:public GUIElement {
public:
  CycleButton(AGUIX *aguix,int x,int y,int width,
              int fg,int bg,int data);
  CycleButton(AGUIX *aguix,int x,int y,int width,int height,
              int fg,int bg,int data);
  virtual ~CycleButton();
  CycleButton( const CycleButton &other );
  CycleButton &operator=( const CycleButton &other );

  char *getOption(int);
  int addOption(const char *);
  int setOption( int, const char * );
  int getSelectedOption() const;
  void setFG(int);
  int getFG() const;
  void setBG(int);
  int getBG() const;
  int getData() const;
  void setData(int);
  void setState(int);
  int getState() const;
  virtual void redraw();
  virtual void flush();
  bool isInside(int x,int y) const;
  virtual bool handleMessage(XEvent *E,Message *msg);
  int setFont(char*);
  virtual const char *getType() const;
  virtual bool isType(const char *type) const;
  void setOption(int index);
  int getMaxSize() const;
protected:
  List *options;
  int act_opt;
  int fg;
  int bg;
  int data;
  int state;
  int instate;
  AGUIXFont *font;
  static const char *type;
  
  void prepareBG( bool force = false );
};

#endif
